@@ -5,10 +5,16 @@ from itertools import chain
 from typing import Any
 from typing import Iterable
 from typing import Optional
+from typing import Tuple
+from typing import Type
+from typing import Union
 
 from functional_predicates.base import Base
 from functional_predicates.misc import sentinel
 from functional_predicates.predicate import Predicate
+from functional_predicates.predicates.builtin import Callable
+from functional_predicates.predicates.builtin import HasAttr
+from functional_predicates.predicates.builtin import IsInstance
 from functional_predicates.predicates.operator import Contains
 from functional_predicates.predicates.operator import Eq
 from functional_predicates.predicates.operator import GE
@@ -20,8 +26,6 @@ from functional_predicates.predicates.operator import LT
 from functional_predicates.predicates.operator import NE
 from functional_predicates.predicates.operator import Not_
 from functional_predicates.predicates.operator import Truth
-from functional_predicates.predicates.types import Callable
-from functional_predicates.predicates.types import IsInstance
 
 
 class Checker(Base):
@@ -34,6 +38,17 @@ class Checker(Base):
         else:
             self.predicates = predicates
 
+    # builtin
+
+    def callable(self: Checker) -> Checker:  # noqa: A003
+        return self._append(Callable)
+
+    def hasattr(self: Checker, x: str) -> Checker:  # noqa: A003
+        return self._append(HasAttr, x)
+
+    def isinstance(self: Checker, x: Union[Type, Tuple[Type, ...]]) -> Checker:  # noqa: A003
+        return self._append(IsInstance, x)
+
     # operator
 
     def lt(self: Checker, x: Any) -> Checker:
@@ -69,14 +84,6 @@ class Checker(Base):
     def contains(self: Checker, x: Any) -> Checker:
         return self._append(Contains, x)
 
-    # types
-
-    def callable(self: Checker) -> Checker:  # noqa: A003
-        return self._append(Callable)
-
-    def isinstance(self: Checker, x: Any) -> Checker:  # noqa: A003
-        return self._append(IsInstance, x)
-
     # private
 
     def _append(
